@@ -26,4 +26,5 @@
 #' @references 
 #'   \href{https://github.com/Stan125/GREA}{GREA} provides an RStudio add-in to import data using rio.
 #' @seealso \code{\link{import}}, \code{\link{import_list}}, \code{\link{export}}, \code{\link{export_list}}, \code{\link{convert}}, \code{\link{install_formats}}
-NULL 
+"_PACKAGE"
+
